@@ -5,8 +5,8 @@
 ;; Author: Thanos Apollo <public@thanosapollo.org>
 ;; Keywords: extensions youtube videos
 ;; URL: https://thanosapollo.org/projects/yeetube/
-;; Package-Version: 20251028.1659
-;; Package-Revision: 02bc06de12e1
+;; Package-Version: 20251219.2333
+;; Package-Revision: b1093c75ab17
 
 ;; Package-Requires: ((emacs "27.2") (compat "29.1.4.2"))
 
@@ -39,6 +39,7 @@
 ;;; Code:
 
 (require 'compat)
+(require 'image)
 (require 'url)
 (require 'tabulated-list)
 (require 'cl-lib)
@@ -54,6 +55,16 @@
   :group 'external
   :prefix "yeetube-")
 
+(defcustom yeetube-torsocks-program (executable-find "torsocks")
+  "Path for torsocks executable."
+  :type 'string
+  :group 'yeetube)
+
+(defcustom yeetube-ytdlp-program (executable-find "yt-dlp")
+  "Path for yt-dlp executable."
+  :type 'string
+  :group 'yeetube)
+
 (defcustom yeetube-results-limit 20
   "Define a limit for search results."
   :type 'number
@@ -78,7 +89,7 @@
   :group 'yeetube)
 
 (defcustom yeetube-download-directory (or (xdg-user-dir "DOWNLOAD") (getenv "HOME"))
-  "Default directory to downlaod videos."
+  "Default directory to download videos."
   :type 'string
   :group 'yeetube)
 
@@ -171,7 +182,7 @@ Valid options include:
 
 (defvar yeetube-invidious-instances
   '("vid.puffyan.us" "inv.nadeko.net" "invidious.flokinet.to")
-  "List of invidious instaces.")
+  "List of invidious instances.")
 
 (defvar yeetube-content nil
   "Scraped content.")
@@ -291,7 +302,6 @@ If ARG is non-nil, save as a playlist URL."
     (message "Playing: %s" (car (assoc video yeetube-saved-videos)))))
 
 ;;;###autoload
-
 (defun yeetube-remove-saved-video ()
   "Select video to remove from saved videos."
   (interactive)
@@ -301,19 +311,19 @@ If ARG is non-nil, save as a playlist URL."
 
 ;;;###autoload
 (defun yeetube-remove-all-saved-videos ()
-  "Clear yeetube saved."
+  "Clear all saved videos from yeetube."
   (interactive)
   (let ((clear-saved (y-or-n-p "Delete saved?")))
     (when clear-saved
       (setf yeetube-saved-videos nil))))
 
 (defun yeetube-update-saved-videos-list (_symbol new-value _where _environment)
-  "Updated saved videos.
+  "Update saved videos list file.
 
-SYMBOL-NAME is the name of the symbol to update.
-NEW-VALUE is the new value for the symbol.
-OPERATION is the operation to perform.
-WHERE indicates where in the buffer the update should happen."
+This is a variable watcher function that writes NEW-VALUE to the saved
+videos file whenever `yeetube-saved-videos' changes.  _SYMBOL is the
+variable being watched, _WHERE indicates the type of change, and
+_ENVIRONMENT is the lexical environment."
   (with-temp-buffer (find-file (concat user-emacs-directory "yeetube"))
 		    (erase-buffer)
 		    (setf yeetube-saved-videos new-value)
@@ -377,10 +387,10 @@ WHERE indicates where in the buffer the update should happen."
 Image is inserted in BUFFER for ENTRY."
   (let ((url-buffer (current-buffer)))
     (unwind-protect
-        (if-let ((err (plist-get status :error)))
+        (if-let* ((err (plist-get status :error)))
             (message "Error %s in retrieving a thumbnail: %S" (car err) (cdr err))
-          (if-let ((handle (mm-dissect-buffer t))
-                   (image (mm-get-image handle)))
+          (if-let* ((handle (mm-dissect-buffer t))
+                    (image (mm-get-image handle)))
               (progn
                 (setf (image-property image :max-width) (car yeetube-thumbnail-size)
                       (image-property image :max-height) (cdr yeetube-thumbnail-size))
@@ -450,7 +460,7 @@ Image is inserted in BUFFER for ENTRY."
   (yeetube-display-content-from-url (format "https://youtube.com/%s/streams" channel-id)))
 
 (defun yeetube-channel-search (channel-id query)
-  "Search channel with CHANNEL-ID for videoes matching QUERY."
+  "Search channel with CHANNEL-ID for videos matching QUERY."
   (interactive (list (yeetube-channel-id-at-point) (yeetube-read-query)))
   (yeetube-display-content-from-url
    (format "https://youtube.com/%s/search?query=%s"
@@ -568,10 +578,7 @@ Image is inserted in BUFFER for ENTRY."
 
 (add-variable-watcher 'yeetube-saved-videos #'yeetube-update-saved-videos-list)
 
-;; Yeetube Downlaod:
-
-(defvar yeetube-ytdlp (executable-find "yt-dlp")
-  "Path for yt-dlp executable.")
+;; Yeetube Download:
 
 ;;;###autoload
 (defun yeetube-download-change-directory ()
@@ -594,16 +601,16 @@ Image is inserted in BUFFER for ENTRY."
 Optional values:
  NAME for custom file name.
  AUDIO-FORMAT to extract and keep contents as specified audio-format only."
-  (unless (executable-find "yt-dlp")
-    (error "Executable for yt-dlp not found.  Please install yt-dlp"))
-  (let* ((tor-command (when yeetube-enable-tor (executable-find "torsocks")))
+  (unless yeetube-ytdlp-program
+    (error "Executable for yt-dlp not found. Please set yeetube-ytdlp-program"))
+  (let* ((tor-command (when yeetube-enable-tor yeetube-torsocks-program))
          (name-command (when name (format "-o %s" (shell-quote-argument name))))
          (format-command (when audio-format
 			   (format "--extract-audio --audio-format %s"
 				   (shell-quote-argument audio-format))))
          (command (mapconcat 'identity (delq nil
 					     (list tor-command
-						   (executable-find "yt-dlp")
+						   yeetube-ytdlp-program
 						   (shell-quote-argument url)
 						   name-command format-command))
 			     " ")))
@@ -731,7 +738,7 @@ FIELDS-FACE-PAIRS is a list of fields and faces."
   "Return tabulated-list format vector.
 
 If THUMBNAIL-P is non-nil, add thumbnail."
-  (let ((list-format `[("Thumbnail"  ,(/ (window-width) 10) nil)
+  (let ((list-format `[("Thumbnail"  ,(ceiling (/ (float (car yeetube-thumbnail-size)) (frame-char-width))) nil)
 		       ("Title" ,(/ (window-width) 3) t)
 		       ("Views" ,(/ (window-width) 10) yeetube--sort-views)
 		       ("Duration" ,(/ (window-width) 10)  yeetube--sort-duration)
@@ -740,9 +747,9 @@ If THUMBNAIL-P is non-nil, add thumbnail."
     (if thumbnail-p list-format (cl-subseq list-format 1))))
 
 (defun yeetube-tabulated-list (&optional thumbnail-p)
-  "Return a tabulated list, adjusted for `window-width'
+  "Return a tabulated list, adjusted for `window-width'.
 
-If THUMBNAIL-P is non-nil, display thumbnails.."
+If THUMBNAIL-P is non-nil, display thumbnails."
   (let ((thumbnail-p (or thumbnail-p yeetube-display-thumbnails-p)))
     (setf tabulated-list-format (yeetube--tabulated-list-format thumbnail-p)
 	  tabulated-list-entries yeetube-content
